@@ -166,11 +166,11 @@ class IzyTV(object):
     def orange_izy_tv(self, transId, data):
         """
         Checks the status of an airtelmoney transaction for izytv bouquet activation.
-        If the status returned is success (4) the corresponding izytv bouquet will
+        If the status returned is SUCCESS the corresponding izytv bouquet will
             be activated.
-        If the status returned is pending (1) we check if the transaction date is over 6min
+        If the status returned is PENDING we check if the transaction date is over 6min
             in which case it will be declared as failed.
-        If the status returned is fail (3) nothing special is done and activation is aborted.
+        If the status returned is FAIL nothing special is done and activation is aborted.
         Redis database is updated in each scenario.
         """
         trans_info = {
@@ -195,13 +195,7 @@ class IzyTV(object):
         data['status'] = STATUS[rstatus]
         data['info'] = STATUS[rstatus]
 
-        if rstatus == 4:  # Succeeded
-            self.update_Redis(
-                transId,
-                {
-                    "status": "Transaction validée",
-                }
-            )
+        if rstatus == 'SUCCESS':
             params = {
                 'session': '',
                 "operator": data["operator"],
@@ -211,7 +205,7 @@ class IzyTV(object):
                 "device_id": data["device_id"],
                 "solde": data["amount"],
                 "offre_refnum": data["offre_refnum"],
-                "partner_ref": data["partner_ref"]
+                "partner_ref": response['response']['txnid']
             }
             LOGS.logger.info(
                 "[OrangeMoney][{}] Sending bouquet activation for: {}\n".format(
@@ -233,7 +227,7 @@ class IzyTV(object):
                         "info": "Activation reussie",
                     }
                 )
-        elif rstatus == 1 or rstatus == 2:  # Pending
+        elif rstatus in ['PENDING', 'INITIATED']:
             if self.transaction_is_timeout(data["TransactionDate"]):
                 self.update_Redis(
                     transId,
@@ -242,6 +236,14 @@ class IzyTV(object):
                         "info": "Activation annulée",
                     }
                 )
+        elif rstatus in ['EXPIRED','FAILED','NOT FOUND']:
+            self.update_Redis(
+                transId,
+                {
+                    "info": "Activation annulée",
+                }
+            )
+
 
     def update_Redis(self, redis_key, dict):
         """
